/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package hero.main;

import java.net.URL;
import java.util.Collection;

import org.jbpm.env.Environment;
import org.jbpm.env.EnvironmentFactory;
import org.jbpm.env.xml.EnvironmentParser;
import org.ow2.bonita.deployment.XpdlParserException;
import org.ow2.bonita.execution.XpdlExecution;
import org.ow2.bonita.facade.User;
import org.ow2.bonita.facade.XPDLImport;
import org.ow2.bonita.util.BonitaException;

/**
 * @author "Pierre Vigneras"
 * @date Oct 22, 2007
 */
public class ApprovalWorkflow {
	private static final String RESSOURCE = "BonitaSimpleProjectEver_1.0.xpdl";
	private static final String WIRING_CONFIG = "hero/main/environment.xml";
	private static final String PROCESS_NAME = "BonitaSimpleProjectEver";

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		EnvironmentFactory envFactory = EnvironmentParser.parseEnvironmentFactoryFromResource(WIRING_CONFIG);
		Environment environment = envFactory.openEnvironment();

		URL ressourceURL = ApprovalWorkflow.class.getResource(RESSOURCE);
		if (environment == null) throw new RuntimeException();
		try {
			XPDLImport.importDocument(ressourceURL, environment);
		} catch (XpdlParserException e) {
			System.err.println("Ouch! Bad XPDL file? File is: " + RESSOURCE);
			e.printStackTrace();
			System.exit(1);
		}
		try {
			User user = new User(environment);
			XpdlExecution xpdlExecution = user.instanciateProcess(PROCESS_NAME);
			String instanceName = xpdlExecution.getName();

			Collection<String> tasks =  user.getToDoList(instanceName);
			for (String task : tasks){
				System.out.println("Starting task: " + task);
				user.startActivity(instanceName, task);
				user.terminateActivity(instanceName, task);
				System.out.println("Task " + task + " terminated.");
			}
		}catch(BonitaException be) {
			be.printStackTrace();
		}
	}
}
